@@ -31,10 +31,12 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Manage resource types
  */
-class CronControllerScripts extends \Hubzero\Base\Object
+class CronControllerScripts extends JObject
 {
 	/**
 	 * Determines task being called and attempts to execute it
@@ -45,11 +47,11 @@ class CronControllerScripts extends \Hubzero\Base\Object
 	{
 		$this->database = JFactory::getDBO();
 
-		$model = new CronTableJob($this->database);
+		$model = new CronJob($this->database);
 
 		$this->filters = array(
 			'state'    => 1,
-			'next_run' => JFactory::getDate()->toSql()
+			'next_run' => date('Y-m-d H:i:s', time())
 		);
 
 		$this->results = $model->getJobs($this->filters);
@@ -84,14 +86,14 @@ class CronControllerScripts extends \Hubzero\Base\Object
 
 				$cron = Cron\CronExpression::factory($row->recurrence);
 
-				$json['last_run'] = $model->last_run = JHTML::_('date', JFactory::getDate(), 'Y-m-d H:i:s'); //JFactory::getDate()->toSql();
+				$json['last_run'] = $model->last_run = date('Y-m-d H:i:s', time()); //$cron->getPreviousRunDate()->format('Y-m-d H:i:s');
 				$json['next_run'] = $model->next_run = $cron->getNextRunDate()->format('Y-m-d H:i:s');
 				$json['active']   = $model->active   = 1;
 
 				$model->store();
 
 				JPluginHelper::importPlugin('cron');
-				$dispatcher = JDispatcher::getInstance();
+				$dispatcher =& JDispatcher::getInstance();
 
 				// Show related content
 				$results = $dispatcher->trigger($row->event);
